import axios from 'axios'
import {ADOBE_ORG_ID} from './config'

const DEMDEX_URL = 'https://mpispain.demdex.net/event'

const paramsFactory = ({infojobsVisitorId, adobeVisitorId}) => ({
  d_mid: infojobsVisitorId || adobeVisitorId,
  d_orgid: ADOBE_ORG_ID,
  d_rtbd: 'json',
  d_full: 1,
  d_cts: 2
})

const shouldSync = dmpResponse =>
  dmpResponse.stuff && dmpResponse.stuff[0] && Boolean(dmpResponse.stuff[0].cv)

const getSyncIds = dmpResponse =>
  dmpResponse.stuff[0].cv
    .split(/(\d+)/)
    .map(str => +str)
    .filter(Boolean)

const defaultImageFactory = () => {
  return new window.Image()
}

const googleSync = ({ids, imageFactory = defaultImageFactory}) => {
  const googleAdsImg = imageFactory()
  googleAdsImg.src = `https://googleads.g.doubleclick.net/pagead/viewthroughconversion/1070383761/?guid=ON&script=0&data=aam=${ids.join(
    ';aam='
  )}&value=0`
  googleAdsImg.onload = function() {
    console.log('segment in google Ads created', ids)
  }
  googleAdsImg.onerror = function() {
    console.log('error creating segments in google ads')
  }
}

const facebookSync = ({ids, imageFactory = defaultImageFactory}) => {
  const facebookAdsImg = imageFactory()
  facebookAdsImg.src = `https://www.facebook.com/tr/?id=547817492518538&ev=Adobe-Audience-Manager-Segment&cd[segId]=${ids.join(
    ','
  )}&noscript=1`
  facebookAdsImg.onload = function() {
    console.log('segment in fb Ads created', ids)
  }
  facebookAdsImg.onerror = function() {
    console.log('error creating segments in fb ads')
  }
}

const track = ({adobeVisitorId, infojobsVisitorId}) =>
  axios.get(DEMDEX_URL, {
    params: paramsFactory({adobeVisitorId, infojobsVisitorId})
  })

export default async ({adobeVisitorId, infojobsVisitorId, imageFactory}) => {
  try {
    const dmpResponse = await track({infojobsVisitorId, adobeVisitorId})
    if (shouldSync(dmpResponse)) {
      const ids = getSyncIds(dmpResponse)
      googleSync({ids, imageFactory})
      facebookSync({ids, imageFactory})
    }
  } catch (error) {
    console.error('rubik:dmp-track', error)
  }
}
