import sinon from 'sinon'
import dmpTrack from '../../src/analytics/dmp/track'
const axios = require('axios')

describe('dmp track', () => {
  const ADOBE_VISITOR_ID = 'fakeAdobeId'
  const IJ_VISITOR_ID = 'fakeIjId'
  let axiosStub

  beforeEach(() => {
    axiosStub = sinon.stub(axios, 'get').resolves({
      stuff: [
        {
          cv: '1234*5678'
        }
      ]
    })
  })

  afterEach(() => {
    axiosStub.restore()
  })

  it('sent track event to the dmp', async () => {
    await dmpTrack({
      infojobsVisitorId: IJ_VISITOR_ID,
      adobeVisitorId: ADOBE_VISITOR_ID,
      imageFactory: () => {}
    })
    sinon.assert.callCount(axiosStub, 1)
    sinon.assert.calledWith(axiosStub, 'https://mpispain.demdex.net/event', {
      params: {
        d_cts: 2,
        d_full: 1,
        d_mid: 'fakeIjId',
        d_orgid: '05FF6243578784B37F000101@AdobeOrg',
        d_rtbd: 'json'
      }
    })
  })

  it('loads the google and facebook pixels', async () => {
    const images = []
    await dmpTrack({
      infojobsVisitorId: IJ_VISITOR_ID,
      adobeVisitorId: ADOBE_VISITOR_ID,
      imageFactory: () => {
        const image = {}
        images.push(image)
        return image
      }
    })
    sinon.assert.match(images.length, 2)
    sinon.assert.match(
      images[0].src,
      'https://googleads.g.doubleclick.net/pagead/viewthroughconversion/1070383761/?guid=ON&script=0&data=aam=1234;aam=5678&value=0'
    )
    sinon.assert.match(
      images[1].src,
      'https://www.facebook.com/tr/?id=547817492518538&ev=Adobe-Audience-Manager-Segment&cd[segId]=1234,5678&noscript=1'
    )
  })
})
